﻿using Medic.Data;
using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Mvc.RazorPages;
using Microsoft.EntityFrameworkCore;
using System.ComponentModel.DataAnnotations;
using RequiredAttribute
    = Medic.Data.RequiredAttribute
    ;

namespace Medic.Pages.Workplace
{





    /// <summary>
    /// The model for workplace index
    /// </summary>
    public class IndexModel : PageModel
    {


        /// <summary>
        /// Select a workplace for this medic
        /// </summary>
        [
           ModelBinder
       ]
        public int Medic
        {
            get; set;
        }









        /// <summary>
        /// The pattern to search for in <see cref="P:Workplace.Name" />
        /// </summary>
        [Required, ModelBinder,
            AutoTrim
       ]
        public string?
        NameSearch
        {
            get
            ; set
            ;
        }
        /// <summary>
        /// A recorded exception if one occurs
        /// </summary>
        public InvalidOperationException?
            DatabaseFailure { get; private set; }


        /// <summary>
        /// Enumerates all workplaces matching <see cref="IndexModel.Pattern"/>
        /// </summary>
        public
        IEnumerator
         <Data.Workplace
         >?
          Enumerator
         ;
        private readonly MedicContext _context;







        public IndexModel(MedicContext context)
        {
            this.
              _context = context;
        }



        public
        void
         OnGet
        (
        )
        {
            if (this._context.Workplaces
                    is DbSet<Data.
       Workplace
        > workplaces
           )
                try
                {
                    this.
             Enumerator
              = (this.NameSearch
              is string pattern && !
                string.IsNullOrWhiteSpace(pattern
              )
               ?
               workplaces.Where(
                   wp => wp.Name.Contains(
                       pattern
                   )
               )
                 :
                workplaces

              ).
              GetEnumerator
               ()
             ;

                }
                catch (
                  InvalidOperationException ex
              )
                {
                    this.DatabaseFailure
                     = ex;
                }
        }
    }
}